.. _session_module:

:mod:`pyramid.session`
---------------------------

.. automodule:: pyramid.session

  .. autofunction:: SignedCookieSessionFactory

  .. autofunction:: BaseCookieSessionFactory

  .. autoclass:: PickleSerializer

  .. autoclass:: JSONSerializer

